==> more_leaf_particles-0.3.0%2B1.21.8-sources.jar: net/fellter/moreLeafParticles/mixin/TintedParticleLeavesBlockMixin.java <==
package net.fellter.moreLeafParticles.mixin;

import com.llamalad7.mixinextras.expression.Definition;
import com.llamalad7.mixinextras.expression.Expression;
import com.llamalad7.mixinextras.sugar.Local;
import net.fellter.moreLeafParticles.ModParticles;
import net.minecraft.class_10716;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2397;
import net.minecraft.class_9381;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.ModifyVariable;

@Mixin(class_10716.class)
public abstract class TintedParticleLeavesBlockMixin extends class_2397 {
	public TintedParticleLeavesBlockMixin(float leafParticleChance, class_2251 settings) {
		super(leafParticleChance, settings);
	}

	@Definition(id = "tintedParticleEffect", local = @Local(type = class_9381.class))
	@Expression("tintedParticleEffect")
	@ModifyVariable(method = "spawnLeafParticle", at = @At("MIXINEXTRAS:EXPRESSION"))
	private class_9381 fellter$spawnLeafParticle(class_9381 value, class_1937 world, class_2338 pos) {
		if (this == class_2246.field_9988) {
			return class_9381.method_58256(ModParticles.SPRUCE_NEEDLES, world.method_67233(pos));
		} else if (this == class_2246.field_10539) {
			return class_9381.method_58256(ModParticles.BIRCH_LEAVES, world.method_67233(pos));
		} else if (this == class_2246.field_37551) {
			return class_9381.method_58256(ModParticles.MANGROVE_LEAVES, world.method_67233(pos));
		} else if (this == class_2246.field_10335) {
			return class_9381.method_58256(ModParticles.JUNGLE_LEAVES, world.method_67233(pos));
		} else if (this == class_2246.field_10098) {
			return class_9381.method_58256(ModParticles.ACACIA_LEAVES, world.method_67233(pos));
		}

		return value;
	}
}

==> more_leaf_particles-1.0.0%2B1.21.8-sources.jar: net/fellter/moreLeafParticles/mixin/TintedParticleLeavesBlockMixin.java <==
package net.fellter.moreLeafParticles.mixin;

import com.llamalad7.mixinextras.expression.Definition;
import com.llamalad7.mixinextras.expression.Expression;
import com.llamalad7.mixinextras.sugar.Local;
import net.fellter.moreLeafParticles.ModParticles;
import net.fellter.moreLeafParticles.MoreLeafParticles;
import net.fellter.moreLeafParticles.yacl.YACLImpl;
import net.minecraft.class_10716;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2397;
import net.minecraft.class_9381;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.ModifyVariable;

@Mixin(class_10716.class)
public abstract class TintedParticleLeavesBlockMixin extends class_2397 {
	public TintedParticleLeavesBlockMixin(float leafParticleChance, class_2251 settings) {
		super(leafParticleChance, settings);
	}

	@Definition(id = "tintedParticleEffect", local = @Local(type = class_9381.class))
	@Expression("tintedParticleEffect")
	@ModifyVariable(method = "spawnLeafParticle", at = @At("MIXINEXTRAS:EXPRESSION"))
	private class_9381 fellter$spawnLeafParticle(class_9381 value, class_1937 world, class_2338 pos) {
		if (MoreLeafParticles.isYACLPresent()) {
			class_9381 effect = YACLImpl.getTintedFromConfig(this, world, pos);
			return effect == null ? value : effect;
		}

		if (this == class_2246.field_9988) {
			return class_9381.method_58256(ModParticles.SPRUCE_NEEDLES, world.method_67233(pos));
		} else if (this == class_2246.field_10539) {
			return class_9381.method_58256(ModParticles.BIRCH_LEAVES, world.method_67233(pos));
		} else if (this == class_2246.field_37551) {
			return class_9381.method_58256(ModParticles.MANGROVE_LEAVES, world.method_67233(pos));
		} else if (this == class_2246.field_10335) {
			return class_9381.method_58256(ModParticles.JUNGLE_LEAVES, world.method_67233(pos));
		} else if (this == class_2246.field_10098) {
			return class_9381.method_58256(ModParticles.ACACIA_LEAVES, world.method_67233(pos));
		}

		return value;
	}
}
